# RoadMap

Voici les developpement à mener sur PytCube:

* [] Ajouter des méthodes de calcul de statistique (pourcentage de la grid couverte par, nombre de chunk ouvert, ..)
* [] Ajouter des méthodes de visualisation (verification de colocalisation)
* [] Ajouter les exemples ERA5, ERSATAR, AVISO, ...
